@@ -7,12 +7,12 @@ def update():
     """
     updates a virtualenv (pip install requirements.txt)
     """
-    do_run('cd %(path)s; bin/pip install -r requirements.txt' % config.sites["main"].deployment)
+    do_run('cd %(path)s; bin/pip install -r requirements.txt --upgrade' % config.sites["main"].deployment)
 
 @task
 def create():
     """
     creates a virtualenv and calls update
     """
-    do_run('cd %(path)s; virtualenv . ' % config.sites["main"].deployment)
+    do_run('cd %(path)s; virtualenv . --system-site-packages' % config.sites["main"].deployment)
     update()
